/*
 * Copyright (c) 2006 Extreme! Lab, Indiana University. All rights reserved.
 *
 * This software is open source. See the bottom of this file for the license.
 *
 * $Id: XBayaTextField.java,v 1.8 2006/11/30 04:17:49 sshirasu Exp $
 */
package edu.indiana.extreme.xbaya.gui;

import java.net.URI;

import javax.swing.JTextField;

import edu.indiana.extreme.xbaya.util.StringUtil;

/**
 * @author Satoshi Shirasuna
 */
public class XBayaTextField implements XBayaTextComponent {

    /**
     * DEFAULT_COLUMNS
     */
    public static final int DEFAULT_COLUMNS = 30;

    private JTextField textArea;

    /**
     * Constructs a XBayaTextArea.
     */
    public XBayaTextField() {
        init();
    }

    /**
     * @return The swing component.
     */
    public JTextField getSwingComponent() {
        return getTextField();
    }

    /**
     * @param uri
     */
    public void setText(URI uri) {
        setText(StringUtil.toString(uri));
    }

    /**
     * @param text
     */
    public void setText(String text) {
        if (text == null) {
            text = "";
        } else {
            text = text.trim();
        }
        this.textArea.setText(text);
        this.textArea.setCaretPosition(0);
    }

    /**
     * @return The text. It never returns null.
     */
    public String getText() {
        return this.textArea.getText().trim();
    }

    /**
     * @return The text field
     */
    public JTextField getTextField() {
        return this.textArea;
    }

    /**
     * @param editable
     */
    public void setEditable(boolean editable) {
        this.textArea.setEditable(editable);
    }

    /**
     * @param columns
     */
    public void setColumns(int columns) {
        this.textArea.setColumns(columns);
    }

    /**
     * Sets whether or not this component is enabled.
     * 
     * @param enabled
     */
    public void setEnabled(boolean enabled) {
        this.textArea.setEnabled(enabled);
    }

    private void init() {
        this.textArea = new JTextField(DEFAULT_COLUMNS);
        this.textArea.setEditable(true);
    }
}

/*
 * Indiana University Extreme! Lab Software License, Version 1.2
 * 
 * Copyright (c) 2006 The Trustees of Indiana University. All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 * 
 * 1) All redistributions of source code must retain the above copyright notice,
 * the list of authors in the original source code, this list of conditions and
 * the disclaimer listed in this license;
 * 
 * 2) All redistributions in binary form must reproduce the above copyright
 * notice, this list of conditions and the disclaimer listed in this license in
 * the documentation and/or other materials provided with the distribution;
 * 
 * 3) Any documentation included with all redistributions must include the
 * following acknowledgement:
 * 
 * "This product includes software developed by the Indiana University Extreme!
 * Lab. For further information please visit http://www.extreme.indiana.edu/"
 * 
 * Alternatively, this acknowledgment may appear in the software itself, and
 * wherever such third-party acknowledgments normally appear.
 * 
 * 4) The name "Indiana University" or "Indiana University Extreme! Lab" shall
 * not be used to endorse or promote products derived from this software without
 * prior written permission from Indiana University. For written permission,
 * please contact http://www.extreme.indiana.edu/.
 * 
 * 5) Products derived from this software may not use "Indiana University" name
 * nor may "Indiana University" appear in their name, without prior written
 * permission of the Indiana University.
 * 
 * Indiana University provides no reassurances that the source code provided
 * does not infringe the patent or any other intellectual property rights of any
 * other entity. Indiana University disclaims any liability to any recipient for
 * claims brought by any other entity based on infringement of intellectual
 * property rights or otherwise.
 * 
 * LICENSEE UNDERSTANDS THAT SOFTWARE IS PROVIDED "AS IS" FOR WHICH NO
 * WARRANTIES AS TO CAPABILITIES OR ACCURACY ARE MADE. INDIANA UNIVERSITY GIVES
 * NO WARRANTIES AND MAKES NO REPRESENTATION THAT SOFTWARE IS FREE OF
 * INFRINGEMENT OF THIRD PARTY PATENT, COPYRIGHT, OR OTHER PROPRIETARY RIGHTS.
 * INDIANA UNIVERSITY MAKES NO WARRANTIES THAT SOFTWARE IS FREE FROM "BUGS",
 * "VIRUSES", "TROJAN HORSES", "TRAP DOORS", "WORMS", OR OTHER HARMFUL CODE.
 * LICENSEE ASSUMES THE ENTIRE RISK AS TO THE PERFORMANCE OF SOFTWARE AND/OR
 * ASSOCIATED MATERIALS, AND TO THE PERFORMANCE AND VALIDITY OF INFORMATION
 * GENERATED USING SOFTWARE.
 */
